translate.storage.oo.oomultifile

Package translate :: Package storage :: Module oo :: Class oomultifile |
[hide private]
[frames] | no frames]

# Class oomultifile

source code

this takes a huge GSI file and represents it as multiple smaller files...

Instance Methods | [hide private]
__init__(self, filename, mode=None, multifilestyle=`'``single``'`) initialises oomultifile from a seekable inputfile or writable outputfile | source code
createsubfileindex(self) reads in all the lines and works out the subfiles | source code
getsubfilename(self, line) looks up the subfile name for the line | source code
listsubfiles(self) returns a list of subfiles in the file | source code
__iter__(self) iterates through the subfile names | source code
__contains__(self, pathname) checks if this pathname is a valid subfile | source code
getsubfilesrc(self, subfile) returns the list of lines matching the subfile | source code
openinputfile(self, subfile) returns a pseudo-file object for the given subfile | source code
openoutputfile(self, subfile) returns a pseudo-file object for the given subfile | source code
getoofile(self, subfile) returns an oofile built up from the given subfile's lines | source code